<?php
/**
 * @package Sj News Ajax Tabs
 * @version 3.1.0
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @copyright (c) 2012 YouTech Company. All Rights Reserved.
 * @author YouTech Company http://www.smartaddons.com
 *
 */
 
defined('_JEXEC') or die;

use Joomla\CMS\Access\Access;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Uri\Uri;
use Joomla\Component\Content\Site\Helper\RouteHelper;

include_once dirname(__FILE__) . '/helper_base.php';

class NewsAjaxtabsHelper extends NewsAjaxtabsBaseHelper {

	public static function getList($params,$module){
		$categories = JCategories::getInstance('Content');
		$catids = $params->get('catid');
		$catid_preload = $params->get('category_preload');
		$input = JFactory::getApplication()->input;
		settype($catid, 'array');
		$list = array();
		$cats = array();
		if(!empty($catids)) {
			$catid_loadfirst = $catids[0];
			$preload_cookie = $module->module . '_' . $module->id;
			if( $input->getInt($preload_cookie, -1, 'cookie') != -1){
				$preload_cookie_value = $input->getInt($preload_cookie, -1, 'cookie');
				if ( in_array($preload_cookie_value, $catids) ){
					$catid_loadfirst = $preload_cookie_value;
				}
			} else if(isset($catid_preload) && in_array($catid_preload, $catids)) {
				$catid_loadfirst = (int)$catid_preload;
			}
			
			foreach ($catids as $i => $cid){
				
				$category = $categories->get($cid);
				$cats[$i] = $category;
				if(!empty($category)) {
					
				}else{
					unset($cats[$i]);
					$catid_loadfirst = $catids[0];
				}
				
			}	
			if(!empty($cats)){
				foreach($cats as $cat){
					$cat->child = self::getArticles($catid_loadfirst, $params);
					$list[$cat->id] = $cat;					
				}
			}
			return $list;
		}
	
	}
	public static function getArticles ($catids, $params){
		$app = Factory::getApplication();

		/** @var \Joomla\Component\Content\Site\Model\ArticlesModel $model */
		$model = $app->bootComponent('com_content')
			->getMVCFactory()->createModel('Articles', 'Site', ['ignore_request' => true]);

		// Set application parameters in model
		$appParams = $app->getParams();
		$model->setState('params', $appParams);

		$model->setState('list.start', 0);
		$model->setState('filter.published', 1);

		// Set the filters based on the module params
		$model->setState('list.limit', (int) $params->get('count', 0));

		// This module does not use tags data
		$model->setState('load_tags', false);

		// Access filter
		$access     = !ComponentHelper::getParams('com_content')->get('show_noauth');
		$authorised = Access::getAuthorisedViewLevels(Factory::getUser()->get('id'));
		$model->setState('filter.access', $access);


		$model->setState('filter.category_id', $catids);

		// Filter by language
		$model->setState('filter.language', $app->getLanguageFilter());
		
		$model->setState('filter.featured', $params->get('show_front', 'show'));

        // Find current Article ID if on an article page
        $option = $app->input->get('option');
        $view = $app->input->get('view');

		// Filter by id in case it should be excluded
		if ($app->input->get('option') === 'com_content'
			&& $app->input->get('view') === 'article')
		{
			// Exclude the current article from displaying in this module
			$model->setState('filter.article_id', $app->input->get('id', 0, 'UINT'));
			$model->setState('filter.article_id.include', false);
		}

        // Ordering
        $model->setState('list.ordering', $params->get('article_ordering', 'a.ordering'));
        $model->setState('list.direction', $params->get('article_ordering_direction', 'ASC'));

		// Retrieve Content
		$items = $model->getItems();
	
		foreach ($items as &$item)
		{
			$item->readmore = \strlen(trim($item->fulltext));
			$item->slug     = $item->id . ':' . $item->alias;

			if ($access || \in_array($item->access, $authorised))
			{
				// We know that user has the privilege to view the article
				$item->link     = Route::_(RouteHelper::getArticleRoute($item->slug, $item->catid, $item->language));
				$item->linkText = Text::_('MOD_ARTICLES_NEWS_READMORE');
			}
			else
			{
				$item->link = new Uri(Route::_('index.php?option=com_users&view=login', false));
				$item->link->setVar('return', base64_encode(RouteHelper::getArticleRoute($item->slug, $item->catid, $item->language)));
				$item->linkText = Text::_('MOD_ARTICLES_NEWS_READMORE_REGISTER');
			}

			$item->introtext = HTMLHelper::_('content.prepare', $item->introtext, '', 'mod_articles_news.content');
			
			$desc_maxlength = $params->get('item_desc_max_characs',50);
			
			$item->introtext =  (new NewsAjaxtabsBaseHelper)->_cleanText($item->introtext);
			$item->introtext = ($item->introtext !='')?(new NewsAjaxtabsBaseHelper)->truncate($item->introtext,$desc_maxlength): '';			

			// Remove any images belongs to the text
			if (!$params->get('image'))
			{
				$item->introtext = preg_replace('/<img[^>]*>/', '', $item->introtext);
			}

			// Show the Intro/Full image field of the article
			if ($params->get('img_intro_full') !== 'none')
			{
				$images = json_decode($item->images);
				$item->imageSrc = '';
				$item->imageAlt = '';
				$item->imageCaption = '';

				if ($params->get('img_intro_full') === 'intro' && !empty($images->image_intro))
				{
					$item->imageSrc = htmlspecialchars($images->image_intro, ENT_COMPAT, 'UTF-8');
					$item->imageAlt = htmlspecialchars($images->image_intro_alt, ENT_COMPAT, 'UTF-8');

					if ($images->image_intro_caption)
					{
						$item->imageCaption = htmlspecialchars($images->image_intro_caption, ENT_COMPAT, 'UTF-8');
					}
				}
				elseif ($params->get('img_intro_full') === 'full' && !empty($images->image_fulltext))
				{
					$item->imageSrc = htmlspecialchars($images->image_fulltext, ENT_COMPAT, 'UTF-8');
					$item->imageAlt = htmlspecialchars($images->image_fulltext_alt, ENT_COMPAT, 'UTF-8');

					if ($images->image_intro_caption)
					{
						$item->imageCaption = htmlspecialchars($images->image_fulltext_caption, ENT_COMPAT, 'UTF-8');
					}
				}
			}

		}

		return $items;
	}
	
}
